import requests
import json
import os

host = "https://secretmessage.pythonanywhere.com"

# ====== Getting Token as User ======
def user(username):
	url = f"{host}/api/create-user/"
	
	data = {
			"name" : username
		}
	response = requests.post(url,data = data)
	
	obj = json.loads(response.text)
	
	return obj["Token"]

# ====== Creating Message ====== 
def create(username,msg,msg_pass):
	url = f"{host}/api/create-message/"
	
	print(f"Connecting {username}.....")
	User = user(username)
	os.system("clear")
	
	headers = {
			"Authorization" : f"Token {User}"	
		}
	data = {
			"text_message" : msg,
			"password" : msg_pass
		}
	
	print("Creating Message.....")	
	response = requests.post(url,headers = headers,data = data)
	os.system("clear")
	
	obj = json.loads(response.text)
	print(json.dumps(obj,indent = 3,ensure_ascii = False))
	
	return obj
	
# =====[] Showing Message ======
def show(username,msg_url,msg_pass):
	url = msg_url
	
	print(f"Connecting {username}.....")
	User = user(username)
	os.system("clear")
	
	headers = {
			"Authorization" : f"Token {User}"	
		}
	data = {
			"password" : msg_pass
		}
	
	print("Getting The Message......")	
	response = requests.post(url,headers = headers,data = data)
	os.system("clear")
	
	obj = json.loads(response.text)
	print(json.dumps(obj["Message"],indent = 3,ensure_ascii = False))
	
	return obj

# ====== Message History ======
def history(username):
	url = f"{host}/api/message-history/"
	
	print(f"Connecting {username}.....")
	User = user(username)
	os.system("clear")
	
	headers = {
			"Authorization" : f"Token {User}"	
		}
	
	print("Getting Message History.....")	
	response = requests.get(url,headers = headers)
	os.system("clear")
	
	obj = json.loads(response.text)
	print(json.dumps(obj,indent = 3,ensure_ascii = False))
	
	return obj
	


import setuptools

description = """
# Secret-Message 
[![PyPI](https://img.shields.io/pypi/v/secret-message?color=blueviolet&label=Web-version%20&logo=appveyor&style=plastic)](https://secret-msg.onrender.com/)

[![PyPI](https://img.shields.io/pypi/v/secret-message?color=blue&label=python-package&style=plastic)](https://pypi.org/project/secret-message/)

Create and share Messages in a  **Secret** way.

## Install
```python
pip install secret-message
```

## Import the package
```python
import secret_message

# ------OR------

#from secret_message import create,show,history
```

## Create a Message:
```python
import secret_message as message 

message.create("<USERNAME>","<YOUR_MESSAGE>","<PASSWORD_FOR_THE_MESSAGE>")
```
For creating a message it takes only 3 parameters:
```
1. Username - Just add your name as username(No registration stuff is required.)
	
2. Text Message - You can add your message 
	
3. Message Password = Create a password of your choice for the message you are creating 
```

• Output:
```python
{
  "id": <YOUR_MESSAGE_ID>,
  "text_message": "<YOUR_MESSAGE>",
  "password": "<YOUR_MESSAGE_PASSWORD>",
  "web_msg_link": "<YOUR_MESSAGE_LINK_FOR_WEB>",
  "api_msg_link": "<YOUR_MESSAGE_LINK_FOR_API_CALL>"  
}
```
```
web_message_link - Using this link anyone will be able to access your message from web[Any web browser].

api_msg_link - Using this link anyone will be able to access your message by api call 
```

## Show/Read Message
```python
import secret_message as message

message.show("<USERNAME>","<MESSAGE_LINK>","<PASSWORD_OF_THE_MESSAGE>")
```
For showing or reading someone else's messages,it takes only 3 parameters:
```
1. Username - Just add your name as username(No registration stuff is required.)
	
2. Message Link - This link must the "api_msg_link" in order to read or view the message.
	
3. Password - This must be the exact password for the message created by other user.
```
	
• Output:
```python
{
  "text_message" : "<USER'S_MESSAGE>"
}
```

## Message History 
```python
import secret_message as message

message.history("<Username>")
```
For getting history of your messages,it takes only 1 parameter:
```
1. Username - Just add your name as username(No registration stuff is required.)
```

• Output:
```python
{
  "Messages": [
  	{
  	   "id": <YOUR_MESSAGE_ID>,
  	   "text_message": "<YOUR_MESSAGE>",
  	   "password": "<YOUR_MESSAGE_PASSWORD>",
  	   "web_msg_link": "<YOUR_MESSAGE_LINK_FOR_WEB>",
  	   "api_msg_link": "<YOUR_MESSAGE_LINK_FOR_API_CALL>" 
  	},
  	........,
  ]
}
```


"""          

setuptools.setup(

	name = 'secret_message', 

	version = '0.8',

	author = "E Lusifa Taehyung",

	author_email = "purplebird7613@gmail.com",

	description = "Create and share a Message Secretly.",
	
	long_description = description,
	
    long_description_content_type = 'text/markdown',
  
	
	packages = setuptools.find_packages(),
 
	classifiers = [

    "Programming Language :: Python",

    "License :: OSI Approved :: MIT License",

    "Operating System :: OS Independent",

    ],

) 